Package: spBPS
Title: Bayesian Predictive Stacking for Scalable Geospatial Transfer
        Learning
Version: 2.0-1
Authors@R: c(
    person("Luca", "Presicce", role = c("aut", "cre"), email = "l.presicce@campus.unimib.it", comment = c(ORCID = "0009-0005-7062-3523")),
    person("Sudipto", "Banerjee", role = "aut"))
Maintainer: Luca Presicce <l.presicce@campus.unimib.it>
Author: Luca Presicce [aut, cre] (ORCID:
    <https://orcid.org/0009-0005-7062-3523>),
  Sudipto Banerjee [aut]
Description: Provides functions for Bayesian Predictive Stacking within the Bayesian transfer learning framework for geospatial artificial systems, as introduced in "Bayesian Transfer Learning for Artificially Intelligent Geospatial Systems: A Predictive Stacking Approach" (Presicce and Banerjee, 2025) <doi:10.48550/arXiv.2410.09504>. This methodology enables efficient Bayesian geostatistical modeling, utilizing predictive stacking to improve inference across spatial datasets. The core functions leverage 'C++' for high-performance computation, making the framework well-suited for large-scale spatial data analysis in parallel and distributed computing environments. Designed for scalability, it allows seamless application in computationally demanding scenarios.
Depends: R (>= 1.8.0)
Imports: Rcpp, CVXR (>= 1.8.1), mniw
LinkingTo: Rcpp, RcppArmadillo
Suggests: knitr, rmarkdown, abind, mvnfast, ECOSolveR, foreach,
        parallel, doParallel, tictoc, MBA, RColorBrewer, classInt, sp,
        fields, testthat (>= 3.0.0)
Config/testthat/edition: 3
License: GPL (>= 3)
Encoding: UTF-8
RoxygenNote: 7.3.3
VignetteBuilder: knitr
URL: https://lucapresicce.github.io/spBPS/
NeedsCompilation: yes
Packaged: 2026-05-14 14:03:06 UTC; presi
Repository: CRAN
Date/Publication: 2026-05-14 14:50:02 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-05-14 15:43:08 UTC; unix
Archs: spBPS.so.dSYM
