# Generated by roxygen2: do not edit by hand

S3method(predict,spBPS)
S3method(print,spBPS)
S3method(print,spBPS_pred)
S3method(print,spBPS_pred_summary)
export(bayesMvLMconjugate)
export(pred_bayesMvLMconjugate)
export(spBPS)
export(subset_data)
importFrom(CVXR,Maximize)
importFrom(CVXR,Problem)
importFrom(CVXR,Variable)
importFrom(CVXR,psolve)
importFrom(CVXR,status)
importFrom(CVXR,value)
importFrom(Rcpp,sourceCpp)
importFrom(mniw,rMNorm)
importFrom(mniw,riwish)
importFrom(utils,setTxtProgressBar)
importFrom(utils,txtProgressBar)
useDynLib(spBPS, .registration = TRUE)
