% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RcppExports.R
\name{post_draws_MvT}
\alias{post_draws_MvT}
\title{Sample R draws from the posterior distributions}
\usage{
post_draws_MvT(poster, R, par, p)
}
\arguments{
\item{poster}{\link{list} output from \code{fit_cpp} function}

\item{R}{\link{integer} number of posterior samples}

\item{par}{if \code{TRUE} only \eqn{\beta} and \eqn{\Sigma} are sampled (\eqn{\omega} is omitted)}

\item{p}{\link{integer} if \code{par = TRUE}, it specifies the column number of \eqn{X}}
}
\value{
\link{list} posterior samples
}
\description{
Sample R draws from the posterior distributions
}
